function varargout = pointrheight(Az,El,Height)

%POINTRHEIGHT - Geometry of Azimuth, Elevation and Altitude pointing.
% G = POINTRHEIGHT(AZ,EL,HGT)
%
%   AZ is azimuth at reference site in degrees.
%   EL is elevation at referense site in degrees.
%   HGT is the required altitude of the common volume, in km.
%   The current "reference site" is used. Use the command
%   CHANGERSITE to change it. The default is 'T'.
%
%   Without any output argument, geometry info is printed 
%   to screen.
%
%   Examples:
%
%       >> pointrheight(180,77.3,293)  
%           ==> formatted printout
%
%       >> G = pointrheight(304,37,293) 
%           ==> G is shown in defalt format.
%
%   24-Mar-2002 Jm
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
if nargin ~= 3
    error('Wrong number of input arguments')
end

if ischar(Az), Az = str2num(Az); end
if ischar(El), El = str2num(El); end
if ischar(Height), Height = str2num(Height); end    

G = AzElHgt(Az,El,Height,changersite);
ogeom_setG(G);
    
if nargout == 0
    geom_print(G);
elseif nargout == 1
    varargout{1} = G;    
else
    error('Wrong number of output arguments')
end    
