function [Lat, Lon, Hgt] = GcCToGgr(P)

% Convert from geocentric cartesian coordinates (P) to geographic
% coordinates (Lat, Lon)(in degrees).
% The method is to minimize the distance between th given
% point and an arbitrary point on the spheroid. The minimum 
% is found by first solving numerically (Newton's method) the
% equation for the Lagrange multiplier arising in the constrained
% extremum value problem.

A = 6378.135;
B = 6356.75;

RD = 45/atan(1);

% Initialize iteration

RG = sqrt( P(1)*P(1) + P(2)*P(2) + P(3)*P(3) );
AA = A*A;
BB = B*B;
AAINV = 1/AA;
BBINV = 1/BB;
CA = AAINV * ( P(1)*P(1) + P(2)*P(2));
CB = BBINV * P(3)*P(3);
L = B*(RG-B);
H1 = RG-B; % a very simple initial guess.

% Compute height:

FA = 1/(1 + L*AAINV);
FB = 1/(1 + L*BBINV);
G = CA*FA*FA + CB*FB*FB -1;
DG = (-2)*( CA*AAINV*FA*FA*FA + CB*BBINV*FB*FB*FB);
L = L - G/DG;
xDif = -L*P(1)/(AA+L);
yDif = -L*P(2)/(AA+L);
zDif = -L*P(3)/(BB+L);
H2 = sqrt( xDif*xDif + yDif*yDif + zDif*zDif ); 

if abs(H1-H2)>eps

    H1=H2;
    GcCToGgrHgt;

end

Hgt=H2;

% Compute latitude and longtitude in degrees:

xB = P(1) + xDif;
yB = P(2) + yDif;
zB = P(3) + zDif;
Lat = atan( (AA/BB) * (zB/sqrt(xB*xB + yB*yB))) * RD;
Lon = atan2(yB,xB) * RD;
