function [Az , El, Range] =GcCToLoc(P, gc0, sgM, Site)

global OGEOM

% Returns Az, El (degrees) coordinates and Range on a site, given geocentric 
% cartesian coordinates (P) of the intersection volume, the geocentric cartesian
% coordinates (gc0) of the site, and rotation matrix (sgM) from site frame
% to geocentric frame.

RD = 45/atan(1);

% Get radius vector Q from the site to P, in GcC-coordinates.

    Qg = P - gc0;

% Map Q from geocentric cartesian (Qg) to site cartesian frame (Qs) by 
% multiplying it with the transpose (= inverse) of sgM.

Qs = Qg * sgM;

D12 = Qs(1)*Qs(1) + Qs(2)*Qs(2);
Range = sqrt( D12 + Qs(3)*Qs(3));

if Range < eps
    if Site == OGEOM.rsite
        if ~isempty(OGEOM.refazim)
            Az = OGEOM.refazim;
            El = OGEOM.refelev;               
        else
            fprintf('##  %c range too near to zero.\n',Site);
            fprintf('##  Cannot determine %c Az and El.\n',Site);
            Az = NaN;
            El = NaN;
        end            
    else
        fprintf('##  %c range too near to zero.\n',Site);
        fprintf('##  Cannot determine Az and El \n');
        Az = NaN;
        El = NaN;
    end 
    return               
end    

El = asin( Qs(3) / Range) * RD;

if abs(El-90) > 0.019

    Az = 180 - atan2( Qs(2), Qs(1) ) * RD;
    
else
    % The point P is exactly ahead of the Local site. There is no way
    % to find the azimuth in this case, without further information.
    % And if the original pointing was on geografic lat, long, height
    % system, there certainly cannot be any such auxiliary
    % information. In fact, the only case where we can do anything
    % sensible is that our original pointing would use this
    % particular local site as the reference site, and the pointing
    % would be a pointrrange or pointrheight, with some azimuth A0,
    % and with 90.0 elevation. Then we obviously must choose Az = A0
    % now. In all other cases, we will not try to choose some
    % arbitrary azimuth, but Azim as NaN, and give a warning.

    global OGEOM
    if ( Site == OGEOM.rsite ) 
        if ~isempty(OGEOM.refazim)
            Az = OGEOM.refazim;
            El = OGEOM.refelev;               
        else
            Az = NaN;
        end
    else
        fprintf('\n## ERROR ##### ERROR ######### ERROR #################\n');
        fprintf('##  %c elevation %1.4f is too near to vertical.\n',Site,El);
        fprintf('##  Cannot determine %c azimuth accurately.\n',Site);
        fprintf('##  Make %c the reference site, and\n', Site); 
        fprintf('##  use pointrheight or pointrrange with elevation 90.\n');
        fprintf('######################################################\n\n');
        Az = NaN;
        
%        error ('See the above ERROR message.')
%        ['Position overhead ' Site ' -- cannot determine ' Site ' Azimuth'])
    end  
    
end


