function P = GcrToGcC( Phi, Lda, Hgt)

% Returns the geosentric carteesian coordinates (P) of a point, given
% latitude (Phi), longtitude (Lda) and height (Hgt) above the spheroid.
% Input angles are in degrees.

a = 6378.135;
b = 6356.75;

DR   = atan(1)/45;
PhiX = Phi*DR;
LdaX = Lda*DR;

% Compute the direction Tpsi = tan(Psi) and distance r from 
% Earth center to the point Q = (Phi, Lda=0, Hgt=0):

Tphi = tan(PhiX);
Tpsi = (b/a)*Tphi*(b/a);
aa   = a*a;
bb   = b*b;
R    = sqrt( (aa*aa +bb*bb*Tphi*Tphi) / (aa + bb*Tphi*Tphi) );

% Compute X and Z for the point Q:

X0 = R/(sqrt(1 + Tpsi*Tpsi));
Z0 = R*sqrt( Tpsi*Tpsi / (1 + Tpsi*Tpsi) );

% Add to Q the effect of height and rotate to the correct longtitude:

P(1) = (X0 + Hgt*cos(PhiX) ) * cos(LdaX);
P(2) = (X0 + Hgt*cos(PhiX) ) * sin(LdaX);
P(3) =  Z0 + Hgt*sin(PhiX);
