function [V,t] = GetVol( r1, r2, g, L )

% Compute the "effective intersection volume" (V, km^3),
% and illumination delay (t, microsec), that is the minimum
% pulse lenght required to fully illuminate the intersection volume.
% Formulaes are from Murdin: SNR for the EISCAT UHF system,
% KGI Report NO. 78:1, February 1978, pp.6-7., with D=32m and f=933.5 Mhz.
% r1 = range from Tromso (km)
% r2  = range from the remote site (km).
% g = beam intersection angle (degrees).
% L = pulse lenght (microsec). If L<=0, then the maximum possible
% value of V is returned.

DR = atan(1)/45;

rAve = sqrt(r1*r1 + r2*r2 );

% Murdin's "b", in units of 1/us, when r in km,
% and D=32m and f=933.5Mhz:

b = 40.23 * tan(g*DR/2) / rAve;

% Murdin's "A" (for D=32m, f=933.5Mhz):

A = (1.258*10^(-6)) * (r1*r1*r2*r2/rAve) / sin(g*DR);

% Then the volume (at the moment of maximum illumination):

if L > 0

    V = A*Erf(b*L);
    
else

    V = A;
    
end

% For illumination delay, we take the value of L that gives Erf(bL)=0.90:

t = 1.29/b;
