function P = MxtToGcC( sgM, gc0, Az, El, Hgt)

% Returns the geocenctic cartesian coordinates (P) of a point,
% height above the spheroid (Hgt), as well as rotation matrix (sgM)
% from site frame to geocentric frame, and the geocentric coordinates 
% (gc0) of the site.
% he basic method is to solve an equation of type x = f(x) numerically
% using fixed point method.


Epsilon = 1*10^(-3);
dH      = 1*10^(6);
H       = Hgt;

asM = Get_asM(Az, El);
agM = sgM*asM;

K = 0;

while abs(dH) > Epsilon


    Rge = Range_0(H, El);
    P = RgeToGcC( agM, gc0, Rge);
    dH  = Hgt - Altitude(P);
    H   = H + dH;
    K   = K + 1;
    
 
end   
